@@ -11,7 +11,7 @@ class CommentMixin:
     Helpers for managing comments on a Media
     """
 
-    def media_comments(self, media_id: str) -> List[Comment]:
+    def media_comments(self, media_id: str, amount: int = 0) -> List[Comment]:
         """
         Get comments on a media
 
@@ -19,6 +19,8 @@ class CommentMixin:
         ----------
         media_id: str
             Unique identifier of a Media
+        amount: int, optional
+            Maximum number of media to return, default is 0 - Inf
 
         Returns
         -------
@@ -38,7 +40,9 @@ class CommentMixin:
         )
         get_comments()
         while ((result.get("has_more_comments") and result.get("next_max_id"))
-               or (result.get("has_more_headload_comments") and result.get("next_min_id"))):
+               or (result.get("has_more_headload_comments") and result.get("next_min_id")))
+               and (True if not amount else len(comments) < amount)):
+                
             try:
                 if result.get("has_more_comments"):
                     params = {"max_id": result.get("next_max_id")}
@@ -57,6 +61,10 @@ class CommentMixin:
                 if "Media not found" in str(e):
                     raise MediaNotFound(e, media_id=media_id, **self.last_json)
                 raise e
+            if amount and amount >= len(comments):
+                break
+        if amount:
+            comments = comments[:amount]
         return comments
 
     def media_comment(self, media_id: str, text: str) -> Comment:
